pub struct PeerStore { /* private fields */ }Expand description
Store para operaciones de peers.
Implementations
Sourceimpl PeerStore
impl PeerStore
Sourcepub fn new(conn: Arc<Mutex<Connection>>) -> Self
pub fn new(conn: Arc<Mutex<Connection>>) -> Self
Crea un nuevo PeerStore.
Sourcepub fn update_status(&self, id: Uuid, status: &str) -> Result<()>
pub fn update_status(&self, id: Uuid, status: &str) -> Result<()>
Actualiza el estado del ultimo sync de un peer.
Sourcepub fn record_sync(&self, result: &SyncResult, project: &str) -> Result<()>
pub fn record_sync(&self, result: &SyncResult, project: &str) -> Result<()>
Registra el resultado de un sync en el log.